import { FunctionType } from '/@/api/tigerapi/model/systemModel';
import { SaveEntity, getEntity } from '/@/api/tigerapi/system';
import { FormSchema } from '/@/components/Table';
import { useUserStore } from '/@/store/modules/user';
import { useI18n } from '/@/hooks/web/useI18n';
import { uploadApi } from '/@/api/sys/upload';
import { notification } from 'ant-design-vue';

const { t } = useI18n();

export const getFns: Record<string, FunctionType> = {
  handleSubmit: async (e, ...args) => {
    try {
      const values = await args[0][0].validate();
      args[0][1]({ confirmLoading: true });
      values.AUTH_PROD = useUserStore().getUserInfo.prodCode;
      //   const apiAction = SaveEntity(values, e, 'MES_LINE');
      //   apiAction.then((action) => {
      //     if (action.IsSuccessed) {
      //       args[0][2]();
      //       args[0][3]('success');
      //     }
      //   });
      args[0][2]();
      args[0][3]('success');
    } finally {
      args[0][1]({ confirmLoading: false });
    }
  },
  rvSubmit: (e, ...args) => {
    try {
      args[0][0]({ confirmLoading: true });
      args[0][1]();
      args[0][2]('success');
    } finally {
      args[0][0]({ confirmLoading: false });
    }
  },
};

export const woCfgformSchema: FormSchema[] = [
  {
    field: 'field1',
    component: 'Input',
    label: '字段1',
    colProps: {
      span: 8,
    },
    componentProps: {
      placeholder: '自定义placeholder',
      onChange: (e: any) => {
        console.log(e);
      },
    },
  },
  {
    field: 'field2',
    component: 'Input',
    label: '字段2',
    colProps: {
      span: 8,
    },
  },
  {
    field: 'field3',
    component: 'DatePicker',
    label: '字段3',
    colProps: {
      span: 8,
    },
  },
];

export const prodCfgformSchema: FormSchema[] = [
  {
    field: 'field4',
    component: 'Input',
    label: '字段1',
    required: true,
    colProps: {
      span: 8,
    },
    componentProps: {
      placeholder: '自定义placeholder',
      onChange: (e: any) => {
        console.log(e);
      },
    },
  },
  {
    field: 'field5',
    component: 'Input',
    label: '字段2',
    colProps: {
      span: 8,
    },
  },
  {
    field: 'field6',
    component: 'DatePicker',
    label: '字段3',
    colProps: {
      span: 8,
    },
  },
  {
    field: 'field7',
    component: 'Input',
    label: '字段4',
    colProps: {
      span: 8,
    },
    componentProps: {
      placeholder: '自定义placeholder',
      onChange: (e: any) => {
        console.log(e);
      },
    },
  },
  {
    field: 'field8',
    component: 'Input',
    label: '字段5',
    colProps: {
      span: 8,
    },
  },
  {
    field: 'field9',
    component: 'DatePicker',
    label: '字段6',
    colProps: {
      span: 8,
    },
  },
];

export const xxCfgformSchema: FormSchema[] = [
  {
    field: 'field10',
    component: 'Input',
    label: '字段1',
    colProps: {
      span: 8,
    },
    componentProps: {
      placeholder: '自定义placeholder',
      onChange: (e: any) => {
        console.log(e);
      },
    },
  },
  {
    field: 'field11',
    component: 'Input',
    label: '字段2',
    colProps: {
      span: 8,
    },
  },
  {
    field: 'field12',
    component: 'DatePicker',
    label: '字段3',
    colProps: {
      span: 8,
    },
  },
];

export const woformSchema: FormSchema[] = [
  {
    field: 'PLAN_QTY',
    label: '工单数量',
    component: 'Input',
    required: true,
    colProps: {
      span: 12,
    },
  },
  {
    label: '计划产线',
    field: 'PLAN_LINE',
    component: 'ApiSelect',
    required: true,
    colProps: {
      span: 12,
    },
    componentProps: {
      api: getEntity,
      params: { entityName: 'MES_LINE', sqlcmd: ' 1=1 ' },
      resultField: 'Data.Items',
      labelField: 'LINE_NAME',
      valueField: 'LINE_CODE',
    },
  },
  {
    label: '工艺路线',
    field: 'ROUTE_CODE',
    component: 'Input',
    required: true,
    colProps: {
      span: 12,
    },
  },
  {
    field: 'add',
    component: 'Input',
    label: '1',
    colSlot: 'add',
    defaultValue: 'MES_ROUTE',
    colProps: {
      span: 1,
    },
  },
  {
    field: 'set',
    component: 'Input',
    label: '1',
    colSlot: 'set',
    defaultValue: 'MES_ROUTE',
    colProps: {
      span: 1,
    },
  },
  {
    field: 'fieldsc',
    component: 'Upload',
    label: '打印模板',
    colProps: {
      span: 10,
    },
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
  },
];

//工艺路线弹框返回
export function woGetSelectSuccess(d, u) {
  return {
    ROUTE_CODE: d.values['val'],
    ID: d.values['id'],
  };
}

export function woCustFn(openItemModal: Fn, slotName: string, others: Fn[], ...args) {
  switch (slotName) {
    case 'add':
      openItemModal(true, {
        title: '工艺路线列表',
        schemas: [
          {
            field: 'ROT_CODE',
            component: 'Input',
            label: '工艺路线编码',
            colProps: {
              span: 12,
            },
          },
        ],
        ItemColumns: [
          {
            title: t('工艺路线编码'),
            dataIndex: 'ROT_CODE',
            resizable: true,
            sorter: true,
            width: 200,
          },
          {
            title: t('工艺路线名称'),
            dataIndex: 'ROT_NAME',
            resizable: true,
            sorter: true,
            width: 180,
          },
        ],
        tableName: 'MES_ROUTE',
        rowKey: 'ROT_CODE',
        returnFieldName: 'ROUTE_CODE', //返回值要赋值的字段名称
      });
      break;
    case 'set':
      //   notification.success({
      //     message: '点击了设置按钮',
      //     description: `OK`,
      //     duration: 3,
      //   });
      others[0](true, { rotId: args[0][0], slotName: 'set' });
      break;
    default:
      () => {};
      break;
  }
}
